@@ -87,7 +87,7 @@ func (d Distro) String() string {
 }
 
 func (d Distro) IsRolling() bool {
-	return d.Type == Wolfi || d.Type == ArchLinux || d.Type == Gentoo
+	return d.Type == Wolfi || d.Type == Chainguard || d.Type == ArchLinux || d.Type == Gentoo
 }
 
 // Unsupported Linux distributions
